/* Automatically generated from
   Id: mk-constants.py,v 1.8 2012/01/05 10:15:27 wiml Exp 
   Do not edit this file directly, it will be overwritten 
*/

static struct { const char *name; long value; }  const pcapmodule_DLT[] = {
#ifdef DLT_NULL
{ "DLT_NULL", (DLT_NULL) },
#endif
#ifdef DLT_EN10MB
{ "DLT_EN10MB", (DLT_EN10MB) },
#endif
#ifdef DLT_EN3MB
{ "DLT_EN3MB", (DLT_EN3MB) },
#endif
#ifdef DLT_AX25
{ "DLT_AX25", (DLT_AX25) },
#endif
#ifdef DLT_PRONET
{ "DLT_PRONET", (DLT_PRONET) },
#endif
#ifdef DLT_CHAOS
{ "DLT_CHAOS", (DLT_CHAOS) },
#endif
#ifdef DLT_ARCNET
{ "DLT_ARCNET", (DLT_ARCNET) },
#endif
#ifdef DLT_ARCNET_LINUX
{ "DLT_ARCNET_LINUX", (DLT_ARCNET_LINUX) },
#endif
#ifdef DLT_SLIP
{ "DLT_SLIP", (DLT_SLIP) },
#endif
#ifdef DLT_SLIP_BSDOS
{ "DLT_SLIP_BSDOS", (DLT_SLIP_BSDOS) },
#endif
#ifdef DLT_FDDI
{ "DLT_FDDI", (DLT_FDDI) },
#endif
#ifdef DLT_HIPPI
{ "DLT_HIPPI", (DLT_HIPPI) },
#endif
#ifdef DLT_ATM_RFC1483
{ "DLT_ATM_RFC1483", (DLT_ATM_RFC1483) },
#endif
#ifdef DLT_RAW
{ "DLT_RAW", (DLT_RAW) },
#endif
#ifdef DLT_PPP
{ "DLT_PPP", (DLT_PPP) },
#endif
#ifdef DLT_PPP_BSDOS
{ "DLT_PPP_BSDOS", (DLT_PPP_BSDOS) },
#endif
#ifdef DLT_PPP_SERIAL
{ "DLT_PPP_SERIAL", (DLT_PPP_SERIAL) },
#endif
#ifdef DLT_PPP_ETHER
{ "DLT_PPP_ETHER", (DLT_PPP_ETHER) },
#endif
#ifdef DLT_C_HDLC
{ "DLT_C_HDLC", (DLT_C_HDLC) },
#endif
#ifdef DLT_HDLC
{ "DLT_HDLC", (DLT_HDLC) },
#endif
#ifdef DLT_ATM_CLIP
{ "DLT_ATM_CLIP", (DLT_ATM_CLIP) },
#endif
#ifdef DLT_IEEE802
{ "DLT_IEEE802", (DLT_IEEE802) },
#endif
#ifdef DLT_IEEE802_11
{ "DLT_IEEE802_11", (DLT_IEEE802_11) },
#endif
#ifdef DLT_IEEE802_11_RADIO
{ "DLT_IEEE802_11_RADIO", (DLT_IEEE802_11_RADIO) },
#endif
#ifdef DLT_IEEE802_11_RADIO_AVS
{ "DLT_IEEE802_11_RADIO_AVS", (DLT_IEEE802_11_RADIO_AVS) },
#endif
#ifdef DLT_LOOP
{ "DLT_LOOP", (DLT_LOOP) },
#endif
#ifdef DLT_LINUX_SLL
{ "DLT_LINUX_SLL", (DLT_LINUX_SLL) },
#endif
#ifdef DLT_LTALK
{ "DLT_LTALK", (DLT_LTALK) },
#endif
#ifdef DLT_ECONET
{ "DLT_ECONET", (DLT_ECONET) },
#endif
#ifdef DLT_IPFILTER
{ "DLT_IPFILTER", (DLT_IPFILTER) },
#endif
#ifdef DLT_PFLOG
{ "DLT_PFLOG", (DLT_PFLOG) },
#endif
#ifdef DLT_PFSYNC
{ "DLT_PFSYNC", (DLT_PFSYNC) },
#endif
#ifdef DLT_CISCO_IOS
{ "DLT_CISCO_IOS", (DLT_CISCO_IOS) },
#endif
#ifdef DLT_PRISM_HEADER
{ "DLT_PRISM_HEADER", (DLT_PRISM_HEADER) },
#endif
#ifdef DLT_AIRONET_HEADER
{ "DLT_AIRONET_HEADER", (DLT_AIRONET_HEADER) },
#endif
#ifdef DLT_ENC
{ "DLT_ENC", (DLT_ENC) },
#endif
#ifdef DLT_APPLE_IP_OVER_IEEE1394
{ "DLT_APPLE_IP_OVER_IEEE1394", (DLT_APPLE_IP_OVER_IEEE1394) },
#endif
#ifdef DLT_AURORA
{ "DLT_AURORA", (DLT_AURORA) },
#endif
#ifdef DLT_DOCSIS
{ "DLT_DOCSIS", (DLT_DOCSIS) },
#endif
#ifdef DLT_FRELAY
{ "DLT_FRELAY", (DLT_FRELAY) },
#endif
#ifdef DLT_IP_OVER_FC
{ "DLT_IP_OVER_FC", (DLT_IP_OVER_FC) },
#endif
#ifdef DLT_JUNIPER_ATM1
{ "DLT_JUNIPER_ATM1", (DLT_JUNIPER_ATM1) },
#endif
#ifdef DLT_JUNIPER_ATM2
{ "DLT_JUNIPER_ATM2", (DLT_JUNIPER_ATM2) },
#endif
#ifdef DLT_JUNIPER_ES
{ "DLT_JUNIPER_ES", (DLT_JUNIPER_ES) },
#endif
#ifdef DLT_JUNIPER_GGSN
{ "DLT_JUNIPER_GGSN", (DLT_JUNIPER_GGSN) },
#endif
#ifdef DLT_JUNIPER_MFR
{ "DLT_JUNIPER_MFR", (DLT_JUNIPER_MFR) },
#endif
#ifdef DLT_JUNIPER_MLFR
{ "DLT_JUNIPER_MLFR", (DLT_JUNIPER_MLFR) },
#endif
#ifdef DLT_JUNIPER_MLPPP
{ "DLT_JUNIPER_MLPPP", (DLT_JUNIPER_MLPPP) },
#endif
#ifdef DLT_JUNIPER_MONITOR
{ "DLT_JUNIPER_MONITOR", (DLT_JUNIPER_MONITOR) },
#endif
#ifdef DLT_JUNIPER_SERVICES
{ "DLT_JUNIPER_SERVICES", (DLT_JUNIPER_SERVICES) },
#endif
#ifdef DLT_LINUX_IRDA
{ "DLT_LINUX_IRDA", (DLT_LINUX_IRDA) },
#endif
#ifdef DLT_RIO
{ "DLT_RIO", (DLT_RIO) },
#endif
#ifdef DLT_SUNATM
{ "DLT_SUNATM", (DLT_SUNATM) },
#endif
#ifdef DLT_SYMANTEC_FIREWALL
{ "DLT_SYMANTEC_FIREWALL", (DLT_SYMANTEC_FIREWALL) },
#endif
#ifdef DLT_TZSP
{ "DLT_TZSP", (DLT_TZSP) },
#endif
#ifdef DLT_REDBACK_SMARTEDGE
{ "DLT_REDBACK_SMARTEDGE", (DLT_REDBACK_SMARTEDGE) },
#endif
#ifdef DLT_OLD_PFLOG
{ "DLT_OLD_PFLOG", (DLT_OLD_PFLOG) },
#endif
#ifdef DLT_HHDLC
{ "DLT_HHDLC", (DLT_HHDLC) },
#endif
#ifdef DLT_PCI_EXP
{ "DLT_PCI_EXP", (DLT_PCI_EXP) },
#endif
#ifdef DLT_MTP2_WITH_PHDR
{ "DLT_MTP2_WITH_PHDR", (DLT_MTP2_WITH_PHDR) },
#endif
#ifdef DLT_MTP2
{ "DLT_MTP2", (DLT_MTP2) },
#endif
#ifdef DLT_MTP3
{ "DLT_MTP3", (DLT_MTP3) },
#endif
#ifdef DLT_SCCP
{ "DLT_SCCP", (DLT_SCCP) },
#endif
#ifdef DLT_IBM_SP
{ "DLT_IBM_SP", (DLT_IBM_SP) },
#endif
#ifdef DLT_IBM_SN
{ "DLT_IBM_SN", (DLT_IBM_SN) },
#endif
#ifdef DLT_BACNET_MS_TP
{ "DLT_BACNET_MS_TP", (DLT_BACNET_MS_TP) },
#endif
#ifdef DLT_LINUX_PPP_WITHDIRECTION
{ "DLT_LINUX_PPP_WITHDIRECTION", (DLT_LINUX_PPP_WITHDIRECTION) },
#endif
#ifdef DLT_GPRS_LLC
{ "DLT_GPRS_LLC", (DLT_GPRS_LLC) },
#endif
#ifdef DLT_GPF_T
{ "DLT_GPF_T", (DLT_GPF_T) },
#endif
#ifdef DLT_GPF_F
{ "DLT_GPF_F", (DLT_GPF_F) },
#endif
#ifdef DLT_GCOM_T1E1
{ "DLT_GCOM_T1E1", (DLT_GCOM_T1E1) },
#endif
#ifdef DLT_GCOM_SERIAL
{ "DLT_GCOM_SERIAL", (DLT_GCOM_SERIAL) },
#endif
#ifdef DLT_JUNIPER_PIC_PEER
{ "DLT_JUNIPER_PIC_PEER", (DLT_JUNIPER_PIC_PEER) },
#endif
#ifdef DLT_ERF_ETH
{ "DLT_ERF_ETH", (DLT_ERF_ETH) },
#endif
#ifdef DLT_ERF_POS
{ "DLT_ERF_POS", (DLT_ERF_POS) },
#endif
#ifdef DLT_LINUX_LAPD
{ "DLT_LINUX_LAPD", (DLT_LINUX_LAPD) },
#endif
#ifdef DLT_JUNIPER_ETHER
{ "DLT_JUNIPER_ETHER", (DLT_JUNIPER_ETHER) },
#endif
#ifdef DLT_JUNIPER_PPP
{ "DLT_JUNIPER_PPP", (DLT_JUNIPER_PPP) },
#endif
#ifdef DLT_JUNIPER_PPPOE
{ "DLT_JUNIPER_PPPOE", (DLT_JUNIPER_PPPOE) },
#endif
#ifdef DLT_JUNIPER_PPPOE_ATM
{ "DLT_JUNIPER_PPPOE_ATM", (DLT_JUNIPER_PPPOE_ATM) },
#endif
#ifdef DLT_JUNIPER_FRELAY
{ "DLT_JUNIPER_FRELAY", (DLT_JUNIPER_FRELAY) },
#endif
#ifdef DLT_JUNIPER_CHDLC
{ "DLT_JUNIPER_CHDLC", (DLT_JUNIPER_CHDLC) },
#endif
#ifdef DLT_JUNIPER_ISM
{ "DLT_JUNIPER_ISM", (DLT_JUNIPER_ISM) },
#endif
#ifdef DLT_JUNIPER_ST
{ "DLT_JUNIPER_ST", (DLT_JUNIPER_ST) },
#endif
#ifdef DLT_JUNIPER_VP
{ "DLT_JUNIPER_VP", (DLT_JUNIPER_VP) },
#endif
#ifdef DLT_PPP_PPPD
{ "DLT_PPP_PPPD", (DLT_PPP_PPPD) },
#endif
#ifdef DLT_MFR
{ "DLT_MFR", (DLT_MFR) },
#endif
#ifdef DLT_A429
{ "DLT_A429", (DLT_A429) },
#endif
#ifdef DLT_A653_ICM
{ "DLT_A653_ICM", (DLT_A653_ICM) },
#endif
#ifdef DLT_USB
{ "DLT_USB", (DLT_USB) },
#endif
#ifdef DLT_USB_LINUX
{ "DLT_USB_LINUX", (DLT_USB_LINUX) },
#endif
#ifdef DLT_CAN20B
{ "DLT_CAN20B", (DLT_CAN20B) },
#endif
#ifdef DLT_BLUETOOTH_HCI_H4
{ "DLT_BLUETOOTH_HCI_H4", (DLT_BLUETOOTH_HCI_H4) },
#endif
#ifdef DLT_BLUETOOTH_HCI_H4_WITH_PHDR
{ "DLT_BLUETOOTH_HCI_H4_WITH_PHDR", (DLT_BLUETOOTH_HCI_H4_WITH_PHDR) },
#endif
#ifdef DLT_IEEE802_16_MAC_CPS
{ "DLT_IEEE802_16_MAC_CPS", (DLT_IEEE802_16_MAC_CPS) },
#endif
#ifdef DLT_IEEE802_16_MAC_CPS_RADIO
{ "DLT_IEEE802_16_MAC_CPS_RADIO", (DLT_IEEE802_16_MAC_CPS_RADIO) },
#endif
#ifdef DLT_IEEE802_15_4_LINUX
{ "DLT_IEEE802_15_4_LINUX", (DLT_IEEE802_15_4_LINUX) },
#endif
#ifdef DLT_IEEE802_15_4
{ "DLT_IEEE802_15_4", (DLT_IEEE802_15_4) },
#endif
#ifdef DLT_PPI
{ "DLT_PPI", (DLT_PPI) },
#endif
#ifdef DLT_SITA
{ "DLT_SITA", (DLT_SITA) },
#endif
#ifdef DLT_ERF
{ "DLT_ERF", (DLT_ERF) },
#endif
#ifdef DLT_RAIF1
{ "DLT_RAIF1", (DLT_RAIF1) },
#endif
#ifdef DLT_IPMB
{ "DLT_IPMB", (DLT_IPMB) },
#endif
#ifdef DLT_AX25_KISS
{ "DLT_AX25_KISS", (DLT_AX25_KISS) },
#endif
#ifdef DLT_LAPD
{ "DLT_LAPD", (DLT_LAPD) },
#endif
#ifdef DLT_PPP_WITH_DIR
{ "DLT_PPP_WITH_DIR", (DLT_PPP_WITH_DIR) },
#endif
#ifdef DLT_C_HDLC_WITH_DIR
{ "DLT_C_HDLC_WITH_DIR", (DLT_C_HDLC_WITH_DIR) },
#endif
#ifdef DLT_FRELAY_WITH_DIR
{ "DLT_FRELAY_WITH_DIR", (DLT_FRELAY_WITH_DIR) },
#endif
#ifdef DLT_LAPB_WITH_DIR
{ "DLT_LAPB_WITH_DIR", (DLT_LAPB_WITH_DIR) },
#endif
#ifdef DLT_IPMB_LINUX
{ "DLT_IPMB_LINUX", (DLT_IPMB_LINUX) },
#endif
#ifdef DLT_FLEXRAY
{ "DLT_FLEXRAY", (DLT_FLEXRAY) },
#endif
#ifdef DLT_MOST
{ "DLT_MOST", (DLT_MOST) },
#endif
#ifdef DLT_LIN
{ "DLT_LIN", (DLT_LIN) },
#endif
#ifdef DLT_IEEE802_15_4_NONASK_PHY
{ "DLT_IEEE802_15_4_NONASK_PHY", (DLT_IEEE802_15_4_NONASK_PHY) },
#endif
#ifdef DLT_GSMTAP_UM
{ "DLT_GSMTAP_UM", (DLT_GSMTAP_UM) },
#endif
#ifdef DLT_GSMTAP_ABIS
{ "DLT_GSMTAP_ABIS", (DLT_GSMTAP_ABIS) },
#endif
#ifdef DLT_MPLS
{ "DLT_MPLS", (DLT_MPLS) },
#endif
#ifdef DLT_DECT
{ "DLT_DECT", (DLT_DECT) },
#endif
#ifdef DLT_AOS
{ "DLT_AOS", (DLT_AOS) },
#endif
#ifdef DLT_WIHART
{ "DLT_WIHART", (DLT_WIHART) },
#endif
#ifdef DLT_FC_2
{ "DLT_FC_2", (DLT_FC_2) },
#endif
#ifdef DLT_FC_2_WITH_FRAME_DELIMS
{ "DLT_FC_2_WITH_FRAME_DELIMS", (DLT_FC_2_WITH_FRAME_DELIMS) },
#endif
#ifdef DLT_IPNET
{ "DLT_IPNET", (DLT_IPNET) },
#endif
#ifdef DLT_CAN_SOCKETCAN
{ "DLT_CAN_SOCKETCAN", (DLT_CAN_SOCKETCAN) },
#endif
#ifdef DLT_IPV4
{ "DLT_IPV4", (DLT_IPV4) },
#endif
#ifdef DLT_IPV6
{ "DLT_IPV6", (DLT_IPV6) },
#endif
#ifdef DLT_IEEE802_15_4_NOFCS
{ "DLT_IEEE802_15_4_NOFCS", (DLT_IEEE802_15_4_NOFCS) },
#endif
#ifdef DLT_MUX27010
{ "DLT_MUX27010", (DLT_MUX27010) },
#endif
#ifdef DLT_STANAG_5066_D_PDU
{ "DLT_STANAG_5066_D_PDU", (DLT_STANAG_5066_D_PDU) },
#endif
#ifdef DLT_IPOIB
{ "DLT_IPOIB", (DLT_IPOIB) },
#endif
{ NULL, 0 }
};
